@@ -1,8 +1,24 @@
 import requests
 
 
+
+def extract_id(video):
+    
+    # extract the id
+    if ("youtube.com" in video) and ("/" in video) and ("=" in video):
+        id = video.split("=")[-1]
+    elif ("youtu.be" in video) and ("/" in video):
+        id = video.split("/")[-1]
+    else:
+        id = video
+    return id
+
+
 def qualities():
-    return ["sd", "mq", "hq", "maxres"]
+    
+    # qualities of thumbnail
+    qualities = ["sd", "mq", "hq", "maxres"]
+    return qualities
 
 
 def thumbnail(video, quality='sd'):
@@ -16,15 +32,16 @@ def thumbnail(video, quality='sd'):
       hq - High Quality
       maxres - Maximum Resolution 
     '''
-    if ("youtube.com" in video) and ("/" in video) and ("=" in video):
-        id = video.split("=")[-1]
-    elif ("youtu.be" in video) and ("/" in video):
-        id = video.split("/")[-1]
-    else:
-        id = video
+    
+    # extract the id
+    video_id = extract_id(video)
+    
+    # check the qualities
     if quality not in qualities():
         quality = 'sd'
-    thumbnail = "https://img.youtube.com/vi/" + id + f"/{quality}default.jpg"
+    
+    # thumbnail link
+    thumbnail = f"https://img.youtube.com/vi/{video_id}/{quality}default.jpg"
     return thumbnail
 
 
@@ -41,7 +58,13 @@ def download_thumbnail(video, name='thumbnail.jpg', quality='sd'):
       hq - High Quality
       maxres - Maximum Resolution 
     '''
+    
+    # thumbnail link
     thumbnail = requests.get(thumbnail(video, quality)).content
+    
+    # save thumbnail
     with open(name, "wb") as file:
         file.write(thumbnail)
+    
+    # return name
     return name
